package com.qmth.distributed.print.api.mark;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.teachcloud.common.annotation.OperationLogDetail;
import com.qmth.teachcloud.mark.dto.mark.manage.MarkManageDto;
import com.qmth.teachcloud.common.bean.dto.mark.MarkSettingDto;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.entity.MarkPaper;
import com.qmth.teachcloud.common.enums.log.CustomizedOperationTypeEnum;
import com.qmth.teachcloud.common.service.MarkPaperService;
import com.qmth.teachcloud.common.util.Result;
import com.qmth.teachcloud.common.util.ResultUtil;
import com.qmth.teachcloud.mark.service.MarkTaskService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;

/**
 * <p>
 * 小题信息表 前端控制器
 * </p>
 *
 * @author xf
 * @since 2023-09-22
 */
@Api(tags = "评卷-试卷结构")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_MARK + "/setting")
public class MarkSettingController {

    @Resource
    private MarkPaperService markPaperService;

    @Resource
    private MarkTaskService markTaskService;

    /**
     * 评卷设置数据列表
     */
    @ApiOperation(value = "查询")
    @RequestMapping(value = "/list", method = RequestMethod.POST)
    public Result list(@ApiParam(value = "考试ID", required = true) @RequestParam Long examId,
                       @ApiParam(value = "课程代码") @RequestParam(required = false) String courseCode,
                       @ApiParam(value = "试卷编号") @RequestParam(required = false) String paperNumber,
                       @ApiParam(value = "提交状态") @RequestParam(required = false) Boolean groupStatus,
                       @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                       @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        IPage<MarkSettingDto> markSettingDtoIPage = markPaperService.listPaperSetting(examId, courseCode, paperNumber, groupStatus, pageNumber, pageSize);
        return ResultUtil.ok(markSettingDtoIPage);
    }

    /**
     * 评卷设置数据获取
     */
    @ApiOperation(value = "评卷设置数据获取")
    @RequestMapping(value = "/paper/get", method = RequestMethod.POST)
    public Result paperGet(@ApiParam(value = "考试ID", required = true) @RequestParam Long examId,
                           @ApiParam(value = "试卷编号", required = true) @RequestParam String paperNumber) {
        return ResultUtil.ok(markPaperService.getByExamIdAndPaperNumber(examId, paperNumber));
    }

    /**
     * 评判设置数据保存
     */
    @ApiOperation(value = "评卷设置数据保存")
    @RequestMapping(value = "/paper/save", method = RequestMethod.POST)
    @OperationLogDetail(customizedOperationType = CustomizedOperationTypeEnum.EDIT)
    public Result paperSave(@RequestBody MarkPaper markPaper) {
        markPaperService.savePaperSetting(markPaper);
        return ResultUtil.ok(true);
    }

    /**
     * 评卷管理数据列表
     */
    @ApiOperation(value = "查询")
    @RequestMapping(value = "/summary", method = RequestMethod.POST)
    public Result summary(@ApiParam(value = "考试ID", required = true) @RequestParam Long examId,
                          @ApiParam(value = "课程代码") @RequestParam(required = false) String courseCode,
                          @ApiParam(value = "试卷编号") @RequestParam(required = false) String paperNumber,
                          @ApiParam(value = "完成进度") @RequestParam(required = false) Boolean progressStatus,
                          @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                          @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        IPage<MarkManageDto> markManageDtoIPage = markTaskService.listPaperManage(examId, courseCode, paperNumber, progressStatus, pageNumber, pageSize);
        return ResultUtil.ok(markManageDtoIPage);
    }

    /**
     * 导出评卷员工作量
     */
    @ApiOperation(value = "查询")
    @RequestMapping(value = "/export_marker", method = RequestMethod.POST)
    public void exportMarker(@ApiParam(value = "考试ID", required = true) @RequestParam Long examId,
                             @ApiParam(value = "课程代码") @RequestParam(required = false) String courseCode,
                             @ApiParam(value = "试卷编号") @RequestParam(required = false) String paperNumber,
                             HttpServletResponse response) {
        markTaskService.exportMarker(examId, courseCode, paperNumber, response);
    }
}
